==> aspose_words_cloud-23.10.0-py3-none-any.whl: asposewordscloud/models/xml_color.py <==
# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="xml_color.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class XmlColor(object):
    """Utility class for Color serialization.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alpha': 'int',
        'web': 'str',
        'xml_alpha': 'int',
        'xml_alpha_specified': 'bool'
    }

    attribute_map = {
        'alpha': 'Alpha',
        'web': 'Web',
        'xml_alpha': 'XmlAlpha',
        'xml_alpha_specified': 'XmlAlphaSpecified'
    }

    def __init__(self, alpha=None, web=None, xml_alpha=None):  # noqa: E501
        """XmlColor - a model defined in Swagger"""  # noqa: E501

        self._alpha = None
        self._web = None
        self._xml_alpha = None
        self._xml_alpha_specified = None
        self.discriminator = None

        if alpha is not None:
            self.alpha = alpha
        if web is not None:
            self.web = web
        if xml_alpha is not None:
            self.xml_alpha = xml_alpha

    @property
    def alpha(self):
        """Gets the alpha of this XmlColor.  # noqa: E501

        Gets or sets the Alpha component of color structure.  # noqa: E501

        :return: The alpha of this XmlColor.  # noqa: E501
        :rtype: int
        """
        return self._alpha

    @alpha.setter
    def alpha(self, alpha):
        """Sets the alpha of this XmlColor.

        Gets or sets the Alpha component of color structure.  # noqa: E501

        :param alpha: The alpha of this XmlColor.  # noqa: E501
        :type: int
        """
        self._alpha = alpha

    @property
    def web(self):
        """Gets the web of this XmlColor.  # noqa: E501

        Gets or sets the HTML string color representation.  # noqa: E501

        :return: The web of this XmlColor.  # noqa: E501
        :rtype: str
        """
        return self._web

    @web.setter
    def web(self, web):
        """Sets the web of this XmlColor.

        Gets or sets the HTML string color representation.  # noqa: E501

        :param web: The web of this XmlColor.  # noqa: E501
        :type: str
        """
        self._web = web

    @property
    def xml_alpha(self):
        """Gets the xml_alpha of this XmlColor.  # noqa: E501

        Gets or sets the Alpha wrapper for serialization.  # noqa: E501

        :return: The xml_alpha of this XmlColor.  # noqa: E501
        :rtype: int
        """
        return self._xml_alpha

    @xml_alpha.setter
    def xml_alpha(self, xml_alpha):
        """Sets the xml_alpha of this XmlColor.

        Gets or sets the Alpha wrapper for serialization.  # noqa: E501

        :param xml_alpha: The xml_alpha of this XmlColor.  # noqa: E501
        :type: int
        """
        self._xml_alpha = xml_alpha

    @property
    def xml_alpha_specified(self):
        """Gets the xml_alpha_specified of this XmlColor.  # noqa: E501

        Gets a value indicating whether Alpha is specified.  # noqa: E501

        :return: The xml_alpha_specified of this XmlColor.  # noqa: E501
        :rtype: bool
        """
        return self._xml_alpha_specified



    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, XmlColor):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> aspose_words_cloud-23.11.0-py3-none-any.whl: asposewordscloud/models/xml_color.py <==
# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="xml_color.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class XmlColor(object):
    """Utility class for Color serialization.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alpha': 'int',
        'web': 'str'
    }

    attribute_map = {
        'alpha': 'Alpha',
        'web': 'Web'
    }

    def __init__(self, alpha=None, web=None):  # noqa: E501
        """XmlColor - a model defined in Swagger"""  # noqa: E501

        self._alpha = None
        self._web = None
        self.discriminator = None

        if alpha is not None:
            self.alpha = alpha
        if web is not None:
            self.web = web

    @property
    def alpha(self):
        """Gets the alpha of this XmlColor.  # noqa: E501

        Gets or sets the Alpha component of color structure.  # noqa: E501

        :return: The alpha of this XmlColor.  # noqa: E501
        :rtype: int
        """
        return self._alpha

    @alpha.setter
    def alpha(self, alpha):
        """Sets the alpha of this XmlColor.

        Gets or sets the Alpha component of color structure.  # noqa: E501

        :param alpha: The alpha of this XmlColor.  # noqa: E501
        :type: int
        """
        self._alpha = alpha

    @property
    def web(self):
        """Gets the web of this XmlColor.  # noqa: E501

        Gets or sets the HTML string color representation.  # noqa: E501

        :return: The web of this XmlColor.  # noqa: E501
        :rtype: str
        """
        return self._web

    @web.setter
    def web(self, web):
        """Sets the web of this XmlColor.

        Gets or sets the HTML string color representation.  # noqa: E501

        :param web: The web of this XmlColor.  # noqa: E501
        :type: str
        """
        self._web = web


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, XmlColor):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
